import request from '@/config/axios'

/**
 * 产品分类
 */
export interface CategoryVO {
  /**
   * 分类编号
   */
  id?: number
  /**
   * 父分类编号
   */
  parentId?: number
  /**
   * 分类名称
   */
  name: string
  /**
   * 移动端分类图
   */
  picUrl: string
  /**
   * PC 端分类图
   */
  bigPicUrl?: string
  /**
   * 分类排序
   */
  sort: number
  /**
   * 开启状态
   */
  status: number
}

// 创建商品分类
export const createCategory = (data: CategoryVO) => {
  return request.post({
    url: '/admin-api/crm/erp-product-category/create',
    data,
    isSubmitForm: true
  })
}

// 更新商品分类
export const updateCategory = (data: CategoryVO) => {
  return request.put({ url: '/admin-api/crm/erp-product-category/update', data })
}

// 删除商品分类
export const deleteCategory = (id: number) => {
  return request.delete({ url: `/admin-api/crm/erp-product-category/delete?id=${id}` })
}

// 获得商品分类
export const getCategory = (id: number) => {
  return request.get({ url: `/admin-api/crm/erp-product-category/get?id=${id}` })
}

// 获得商品分类列表
export const getCategoryList = (params: any) => {
  return request.get({ url: '/admin-api/crm/erp-product-category/list', params })
}

// 获得商品分类列表
export const getCategorySimpleList = (params: any) => {
  return request.get({ url: '/admin-api/crm/erp-product-category/simple-list', params })
}
